@@ -141,7 +141,7 @@ construct_Q_n <- function(type, dat_v, vals, return_model=F) {
       time_basis = "continuous",
       SL_control = list(
         # SL.library = rep(c("SL.mean", "SL.glm", "SL.gam", "SL.earth"),2), # Note: rep() is to avoid a SuperLearner bug
-        SL.library = rep(c("SL.mean", "SL.glm", "SL.gam"),2), # Note: rep() is to avoid a SuperLearner bug
+        SL.library = rep(c("SL.mean", "SL.glm", "SL.gam"),3), # Note: rep() is to avoid a SuperLearner bug
         V = 5,
         obsWeights = dat_v$weights
       )
@@ -939,7 +939,8 @@ construct_gamma_n <- function(dat_v, type="Super Learner", omega_n,
     do.call("library", list("SuperLearner"))
     # SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.earth", "SL.loess",
     #                 "SL.nnet", "SL.ksvm", "SL.rpartPrune", "SL.svm")
-    SL.library <- c("SL.mean", "SL.mean", "SL.gam", "SL.gam", "SL.ranger") # Changed on 2024-02-13; SL.mean written twice to avoid SuperLearner bug
+    # SL.library <- c("SL.mean", "SL.mean", "SL.gam", "SL.gam", "SL.ranger") # Changed on 2024-02-13; SL.mean written twice to avoid SuperLearner bug
+    SL.library <- c(rep("SL.mean", dim_x), "SL.gam", "SL.ranger") # Changed on 2024-02-13; SL.mean repeated to avoid SuperLearner bug
 
     model_sl <- suppressWarnings(SuperLearner::SuperLearner(
       Y = dat_v2$po,
